all.Carms<-function(){
     cat("\n")
     note_for_CBZss_input()
     cat("\n")
     note_for_close_window()
     CBZMSpar<-data.frame(subject=c(1,2),TBW=c(0),PB=c(0),VPA=c(0),PHT=c(0),E=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     CBZMSpar<-edit(CBZMSpar)
##     CBZMSpar<-ymscheck(CBZMSpar)
     cat("\n")
     Car.ms(length(CBZMSpar$subject),CBZMSpar$c,CBZMSpar$tau,CBZMSpar$ts,CBZMSpar$D,CBZMSpar$TBW,CBZMSpar$PB,CBZMSpar$VPA,CBZMSpar$PHT,CBZMSpar$E)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_CBZss_output()
     show(samplesStats("*"))
     cat("\n")
     C<-pocpr(1.2,CBZMSpar$D,CBZMSpar$tau,CBZMSpar$ts)  
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)  
     C<-pocpr(1.2,CBZMSpar$D,CBZMSpar$tau,CBZMSpar$tau)  
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)
     cat("\n")
     cal.again()
}